@@ -23,6 +23,14 @@ impl super::Kubectl {
         api::PostParams::default()
     }
 
+    pub fn patch_params(&self) -> api::PatchParams {
+        api::PatchParams::default()
+    }
+
+    pub fn patch_with_manager(&self, manager: &str) -> api::PatchParams {
+        api::PatchParams::apply(manager)
+    }
+
     pub fn api<T>(&self) -> api::Api<T>
     where
         T: kube::Resource,
